@@ -72,7 +72,7 @@ setGeneric("aggregate_cells", function(.data,
   standardGeneric("aggregate_cells"))
 
 
-#' #' Efficiently bind multiple data frames by row and column
+#' Efficiently bind multiple data frames by row and column
 #'
 #' This is an efficient implementation of the common pattern of
 #' `do.call(rbind, dfs)` or `do.call(cbind, dfs)` for binding many
@@ -217,3 +217,49 @@ bind_cols.list <-  function(..., .id = NULL)
 {
   dplyr::bind_cols(..., .id = .id)
 }
+
+#' @name plot_ly
+#' @rdname plot_ly
+#' @inherit plotly::plot_ly
+#' @importFrom plotly plot_ly
+#' 
+#' @export
+plot_ly <- function(data=data.frame(), ..., type=NULL, name=NULL,
+                    color=NULL, colors=NULL, alpha=NULL,
+                    stroke=NULL, strokes=NULL, alpha_stroke=1,
+                    size=NULL, sizes=c(10, 100),
+                    span=NULL, spans=c(1, 20),
+                    symbol=NULL, symbols=NULL,
+                    linetype=NULL, linetypes=NULL,
+                    split=NULL, frame=NULL,
+                    width=NULL, height=NULL, source="A") {
+  UseMethod("plot_ly")
+}
+
+#' @importFrom plotly plot_ly
+#' 
+#' @export
+plot_ly.default <- function(data=data.frame(), 
+                            ..., type=NULL, name=NULL,
+                            color=NULL, colors=NULL, alpha=NULL,
+                            stroke=NULL, strokes=NULL, alpha_stroke=1,
+                            size=NULL, sizes=c(10, 100),
+                            span=NULL, spans=c(1, 20),
+                            symbol=NULL, symbols=NULL,
+                            linetype=NULL, linetypes=NULL,
+                            split=NULL, frame=NULL,
+                            width=NULL, height=NULL, source="A") {
+  
+  class(data) <- class(data)[!class(data) %in% "tbl_df"]
+  
+  plotly::plot_ly(data, ...,
+                  type=type, name=name,
+                  color=color, colors=colors, alpha=alpha,
+                  stroke=stroke, strokes=strokes, alpha_stroke=alpha_stroke,
+                  size=size, sizes=sizes,
+                  span=span, spans=spans,
+                  symbol=symbol, symbols=symbols,
+                  linetype=linetype, linetypes=linetypes,
+                  split=split, frame=frame,
+                  width=width, height=height, source=source)
+}
